import { Component, Prop, h, Host, Element } from '@stencil/core';
import { createColorStyles } from '../../utils/color';
export class ProgressCircleComponent {
    constructor() {
        /** The progress value in percent. Use -1 or undefined for indeterminate loading animation. */
        this.value = -1;
        /** The circle radius in percent. The default size is 200px (radius 100px) but scaled to 100% of parent. */
        this.radius = 100;
        /** The line width in percent. If stroke >= radius then circle is filled (pie). */
        this.stroke = 10;
        /** The line cap shape. For example: `round`. */
        this.shape = 'butt';
    }
    isIndeterminate() {
        return this.value < 0;
    }
    render() {
        const radius = this.radius > 100 ? 100 : this.radius;
        const stroke = this.stroke > radius ? radius : this.stroke;
        const normalizedRadius = radius - stroke / 2;
        const circumference = normalizedRadius * 2 * Math.PI;
        const offset = circumference - (this.value / 100) * circumference;
        return (h(Host, { class: {
                indeterminate: this.isIndeterminate(),
            } },
            h("svg", { viewBox: "0 0 200 200", width: "100%", height: "100%", style: Object.assign({ '--circle-dash': `${circumference}`, '--circle-dash-inv': `${-circumference + 1}` }, createColorStyles(this.color, true)) },
                h("circle", { "stroke-dashoffset": offset, "stroke-width": stroke, "stroke-linecap": this.shape, fill: "transparent", r: normalizedRadius, cx: "100", cy: "100" }))));
    }
    static get is() { return "ui-progress-circle"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() { return {
        "$": ["progress-circle.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["progress-circle.css"]
    }; }
    static get properties() { return {
        "value": {
            "type": "number",
            "mutable": false,
            "complexType": {
                "original": "number",
                "resolved": "number",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The progress value in percent. Use -1 or undefined for indeterminate loading animation."
            },
            "attribute": "value",
            "reflect": false,
            "defaultValue": "-1"
        },
        "radius": {
            "type": "number",
            "mutable": false,
            "complexType": {
                "original": "number",
                "resolved": "number",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The circle radius in percent. The default size is 200px (radius 100px) but scaled to 100% of parent."
            },
            "attribute": "radius",
            "reflect": false,
            "defaultValue": "100"
        },
        "color": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The circle color. Use predefined colors like `info`, `success`, `warning` or `danger` or a custom color like `#123456` or `yellow`."
            },
            "attribute": "color",
            "reflect": false
        },
        "stroke": {
            "type": "number",
            "mutable": false,
            "complexType": {
                "original": "number",
                "resolved": "number",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The line width in percent. If stroke >= radius then circle is filled (pie)."
            },
            "attribute": "stroke",
            "reflect": false,
            "defaultValue": "10"
        },
        "shape": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "CanvasLineCap",
                "resolved": "\"butt\" | \"round\" | \"square\"",
                "references": {
                    "CanvasLineCap": {
                        "location": "global"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The line cap shape. For example: `round`."
            },
            "attribute": "shape",
            "reflect": false,
            "defaultValue": "'butt'"
        }
    }; }
    static get elementRef() { return "el"; }
}
