import { r as registerInstance, h, H as Host, g as getElement } from './index-1ebccb1d.js';
var colors = {
    success: {
        base: '#27ae60',
        contrast: '#ffffff',
    },
    info: {
        base: '#2980b9',
        contrast: '#ffffff',
    },
    warning: {
        base: '#f3d112',
        contrast: '#000000',
    },
    danger: {
        base: '#c0392b',
        contrast: '#ffffff',
    },
};
var createColorStyles = function (name, textOnly) {
    if (textOnly === void 0) { textOnly = false; }
    var color = colors[name] || { base: name, contrast: 'currentColor' };
    return textOnly
        ? {
            color: color.base,
        }
        : {
            'background-color': color.base,
            'color': color.contrast,
        };
};
var progressCircleCss = ":host{display:-ms-inline-flexbox;display:inline-flex;overflow:hidden;width:100%;height:100%}:host svg{width:100%;height:100%}:host circle{-webkit-transition:stroke-dashoffset 300ms;transition:stroke-dashoffset 300ms;-webkit-transform:rotate(-90deg);transform:rotate(-90deg);-webkit-transform-origin:50% 50%;transform-origin:50% 50%;stroke-dasharray:var(--circle-dash);stroke:currentColor}:host(.indeterminate) svg{-webkit-animation:rotate 1.1s linear infinite;animation:rotate 1.1s linear infinite}:host(.indeterminate) svg circle{stroke-dashoffset:0;-webkit-animation:dash 1.8s ease-in-out infinite;animation:dash 1.8s ease-in-out infinite}@-webkit-keyframes rotate{100%{-webkit-transform:rotate(360deg);transform:rotate(360deg)}}@keyframes rotate{100%{-webkit-transform:rotate(360deg);transform:rotate(360deg)}}@-webkit-keyframes dash{0%{stroke-dasharray:0 var(--circle-dash);stroke-dashoffset:0}100%{stroke-dasharray:var(--circle-dash) var(--circle-dash);stroke-dashoffset:var(--circle-dash-inv)}}@keyframes dash{0%{stroke-dasharray:0 var(--circle-dash);stroke-dashoffset:0}100%{stroke-dasharray:var(--circle-dash) var(--circle-dash);stroke-dashoffset:var(--circle-dash-inv)}}";
var ProgressCircleComponent = /** @class */ (function () {
    function ProgressCircleComponent(hostRef) {
        registerInstance(this, hostRef);
        /** The progress value in percent. Use -1 or undefined for indeterminate loading animation. */
        this.value = -1;
        /** The circle radius in percent. The default size is 200px (radius 100px) but scaled to 100% of parent. */
        this.radius = 100;
        /** The line width in percent. If stroke >= radius then circle is filled (pie). */
        this.stroke = 10;
        /** The line cap shape. For example: `round`. */
        this.shape = 'butt';
    }
    ProgressCircleComponent.prototype.isIndeterminate = function () {
        return this.value < 0;
    };
    ProgressCircleComponent.prototype.render = function () {
        var radius = this.radius > 100 ? 100 : this.radius;
        var stroke = this.stroke > radius ? radius : this.stroke;
        var normalizedRadius = radius - stroke / 2;
        var circumference = normalizedRadius * 2 * Math.PI;
        var offset = circumference - (this.value / 100) * circumference;
        return (h(Host, { class: {
                indeterminate: this.isIndeterminate(),
            } }, h("svg", { viewBox: "0 0 200 200", width: "100%", height: "100%", style: Object.assign({ '--circle-dash': "" + circumference, '--circle-dash-inv': "" + (-circumference + 1) }, createColorStyles(this.color, true)) }, h("circle", { "stroke-dashoffset": offset, "stroke-width": stroke, "stroke-linecap": this.shape, fill: "transparent", r: normalizedRadius, cx: "100", cy: "100" }))));
    };
    Object.defineProperty(ProgressCircleComponent.prototype, "el", {
        get: function () { return getElement(this); },
        enumerable: false,
        configurable: true
    });
    return ProgressCircleComponent;
}());
ProgressCircleComponent.style = progressCircleCss;
export { ProgressCircleComponent as ui_progress_circle };
